Pundit.NotAuthorizedError exception (pundit v1.1.1)
View SourceException raised when a user attempts to perform an action they're not authorized to perform.
Exception raised when a user attempts to perform an action they're not authorized to perform.